@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Manipulate the position of a note in a scale
 
-our $VERSION = '0.0401';
+our $VERSION = '0.0500';
 
 use Carp;
 use Moo;
@@ -35,7 +35,7 @@ has note_format => (
 
 has offset => (
     is      => 'ro',
-    isa     => sub { die 'Not an integer' unless $_[0] =~ /^\d+$/ },
+    isa     => sub { die 'Not a negative or positive integer' unless $_[0] =~ /^-?\d+$/ },
     default => sub { 1 },
 );
 
@@ -127,7 +127,7 @@ Music::ScaleNote - Manipulate the position of a note in a scale
 
 =head1 VERSION
 
-version 0.0401
+version 0.0500
 
 =head1 SYNOPSIS
 
